@@ -3,12 +3,13 @@ Main interface for codeguruprofiler service.
 
 Usage::
 
+    ```python
     import boto3
-    from mypy_boto3.codeguruprofiler import (
+    from mypy_boto3_codeguruprofiler import (
         Client,
         CodeGuruProfilerClient,
         ListProfileTimesPaginator,
-        )
+    )
 
     session = boto3.Session()
 
@@ -16,10 +17,11 @@ Usage::
     session_client: CodeGuruProfilerClient = session.client("codeguruprofiler")
 
     list_profile_times_paginator: ListProfileTimesPaginator = client.get_paginator("list_profile_times")
+    ```
 """
 from mypy_boto3_codeguruprofiler.client import (
-    CodeGuruProfilerClient as Client,
     CodeGuruProfilerClient,
+    CodeGuruProfilerClient as Client,
 )
 from mypy_boto3_codeguruprofiler.paginator import ListProfileTimesPaginator
 
