@@ -3,14 +3,18 @@ Main interface for codeguruprofiler service client paginators.
 
 Usage::
 
+    ```python
     import boto3
-    from mypy_boto3.codeguruprofiler import (
+
+    from mypy_boto3_codeguruprofiler import CodeGuruProfilerClient
+    from mypy_boto3_codeguruprofiler import (
         ListProfileTimesPaginator,
     )
 
     client: CodeGuruProfilerClient = boto3.client("codeguruprofiler")
 
     list_profile_times_paginator: ListProfileTimesPaginator = client.get_paginator("list_profile_times")
+    ```
 """
 # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
 from datetime import datetime
@@ -33,7 +37,7 @@ __all__ = ("ListProfileTimesPaginator",)
 
 class ListProfileTimesPaginator(Boto3Paginator):
     """
-    [Paginator.ListProfileTimes documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/codeguruprofiler.html#CodeGuruProfiler.Paginator.ListProfileTimes)
+    [Paginator.ListProfileTimes documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.0/reference/services/codeguruprofiler.html#CodeGuruProfiler.Paginator.ListProfileTimes)
     """
 
     def paginate(
@@ -46,5 +50,5 @@ class ListProfileTimesPaginator(Boto3Paginator):
         PaginationConfig: PaginatorConfigTypeDef = None,
     ) -> Iterator[ListProfileTimesResponseTypeDef]:
         """
-        [ListProfileTimes.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/codeguruprofiler.html#CodeGuruProfiler.Paginator.ListProfileTimes.paginate)
+        [ListProfileTimes.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.0/reference/services/codeguruprofiler.html#CodeGuruProfiler.Paginator.ListProfileTimes.paginate)
         """
