@@ -3,9 +3,11 @@ Main interface for codeguruprofiler service type definitions.
 
 Usage::
 
-    from mypy_boto3.codeguruprofiler.type_defs import AgentConfigurationTypeDef
+    ```python
+    from mypy_boto3_codeguruprofiler.type_defs import AgentConfigurationTypeDef
 
     data: AgentConfigurationTypeDef = {...}
+    ```
 """
 from datetime import datetime
 import sys
